[m-rev.] trivial diff: rename some types
Julien Fischer
juliensf at csse.unimelb.edu.au
Fri Aug 31 15:59:08 AEST 2007
Estimated hours taken: 0.1
Branches: main
compiler/mlds.m:
compiler/ilds.m:
Give distinct names to the two separate types currently named
call_kind/0.
compiler/ml_elim_nested.m:
Conform to the above change.
Julien.
Index: ilds.m
===================================================================
RCS file: /home/mercury/mercury1/repository/mercury/compiler/ilds.m,v
retrieving revision 1.26
diff -u -r1.26 ilds.m
--- ilds.m 31 Jul 2006 08:31:42 -0000 1.26
+++ ilds.m 31 Aug 2007 05:56:15 -0000
@@ -147,23 +147,23 @@
% The name of a member (method, field, event or property).
%
:- type member_name
- ---> ctor % constructor (initializes instances
- % of this class)
+ ---> ctor % Constructor (initializes instances
+ % of this class).
- ; cctor % class constructor (initializes
+ ; cctor % Class constructor (initializes
% non-instance fields).
- ; id(ilds.id). % ordinary method or field name
+ ; id(ilds.id). % Ordinary method or field name.
% Calling conventions.
%
:- type call_conv
---> call_conv(
- bool, % is this an instance method call?
- call_kind % what kind of call is it
+ bool, % Is this an instance method call?
+ il_call_kind % What kind of call is it?
).
-:- type call_kind
+:- type il_call_kind
---> default
; vararg
; unmanaged_cdecl
Index: ml_elim_nested.m
===================================================================
RCS file: /home/mercury/mercury1/repository/mercury/compiler/ml_elim_nested.m,v
retrieving revision 1.94
diff -u -r1.94 ml_elim_nested.m
--- ml_elim_nested.m 21 Aug 2007 17:40:31 -0000 1.94
+++ ml_elim_nested.m 31 Aug 2007 05:56:15 -0000
@@ -2230,7 +2230,7 @@
).
:- pred add_unchain_stack_to_call(mlds_stmt::in, list(mlds_lval)::in,
- call_kind::in, mlds_context::in, mlds_stmt::out,
+ ml_call_kind::in, mlds_context::in, mlds_stmt::out,
elim_info::in, elim_info::out) is det.
add_unchain_stack_to_call(Stmt0, RetLvals, CallKind, Context, Stmt, !Info) :-
Index: mlds.m
===================================================================
RCS file: /home/mercury/mercury1/repository/mercury/compiler/mlds.m,v
retrieving revision 1.156
diff -u -r1.156 mlds.m
--- mlds.m 31 Aug 2007 05:46:45 -0000 1.156
+++ mlds.m 31 Aug 2007 05:56:15 -0000
@@ -1042,7 +1042,7 @@
list(mlds_rval), % Ordinary function arguments.
list(mlds_lval), % Places to store the function return
% value(s).
- call_kind % Indicates whether this call is a
+ ml_call_kind % Indicates whether this call is a
% tail call.
)
@@ -1182,7 +1182,7 @@
% Extra info for calls
%
% The `call_kind' type indicates whether a call is a tail call
% and whether the call is know to never return.
%
% Marking a call as a tail_call is intended as a hint to
@@ -1195,7 +1195,7 @@
% stack frame and/or which falls through to the following
% statement.
%
-:- type call_kind
+:- type ml_call_kind
---> no_return_call % A call that never returns
% (this is a special case of a tail call)
; tail_call % A tail call.
--------------------------------------------------------------------------
mercury-reviews mailing list
Post messages to: mercury-reviews at csse.unimelb.edu.au
Administrative Queries: owner-mercury-reviews at csse.unimelb.edu.au
Subscriptions: mercury-reviews-request at csse.unimelb.edu.au
--------------------------------------------------------------------------
More information about the reviews
mailing list
@@ -1182,7 +1182,7 @@
% Extra info for calls
%
- % The `call_kind' type indicates whether a call is a tail call
+ % The `ml_call_kind' type indicates whether a call is a tail call
% and whether the call is know to never return.
%